@@ -33,9 +33,10 @@
 #  define KCODECS_DEPRECATED_NO_EXPORT KCODECS_NO_EXPORT KCODECS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCODECS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCODECS_NO_DEPRECATED
+#    define KCODECS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
